@@ -25,33 +25,30 @@
 #include "libglade-buddy.h"
 #include "save-buddy.h"
 
-#include <gnome.h>
 #include <string.h>
 
+#include <glib/gi18n.h>
+#include <gtk/gtkaboutdialog.h>
+#include <gtk/gtkcombobox.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtkoptionmenu.h>
+#include <gtk/gtktextview.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtktreeview.h>
+
+#include <libgnome/gnome-help.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
 #include <unistd.h>
 #include <fcntl.h>
+#include <signal.h>
 #include <sys/types.h>
 #include <sysexits.h>
 #include <sys/wait.h>
 
-#if 0
-static char *help_pages[] = {
-	"index.html",
-	"debug-info.html",
-	"description.html",
-	"updating.html",
-	"product.html",
-	"component.html",
-	"system-config.html",
-	"submit-report.html",
-	"summary.html",
-	NULL
-};
-#endif
-
 static char *state_title[] = {
 	N_("Welcome to Bug Buddy"),
 	N_("Collecting debug info"),
@@ -219,14 +216,14 @@ void
 on_druid_about_clicked (GtkWidget *button, gpointer data)
 {
 	static GtkWidget *about;
-	GdkPixbuf *pixbuf = NULL;
+
 	static const char *authors[] = {
 		"Jacob Berkman  <jacob@bug-buddy.org>",
 		"Fernando Herrera  <fherrera@onirica.com>",
 		NULL
 	};
 
-	static const char *documentors[] = {
+	static const char *documenters[] = {
 		"Telsa Gwynne  <hobbit@aloss.ukuu.org.uk>",
 		"Kevin Conder  <kevin@kevindumpscore.com>",
 		"Eric Baudais  <baudais@kkpsi.org>",
@@ -247,36 +244,24 @@ on_druid_about_clicked (GtkWidget *button, gpointer data)
 		return;
 	}
 		
-	pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-					   "bug-buddy", 48, 0, NULL);
-	
-	about = gnome_about_new (_("Bug Buddy"), VERSION,
-				 "Copyright \xc2\xa9 1999-2002 Jacob Berkman\n"
-				 "Copyright \xc2\xa9 2000-2002 Ximian, Inc.\n"
-				 "Copyright \xc2\xa9 2003-2004 Fernando Herrera",
-				 _("The graphical bug reporting tool for GNOME."),
-				 authors,
-				 documentors,
-				 (strcmp (translators, "translator_credits-PLEASE_ADD_YOURSELF_HERE")
-					 ? translators : NULL), pixbuf);
+	about = gtk_about_dialog_new ();
+
+	gtk_about_dialog_set_name (GTK_ABOUT_DIALOG (about), _("Bug Buddy"));
+	gtk_about_dialog_set_version (GTK_ABOUT_DIALOG (about), VERSION);
+	gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG (about), _("The graphical bug reporting tool for GNOME."));
+	gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG (about), "Copyright \xc2\xa9 1999-2002 Jacob Berkman\n"
+								  "Copyright \xc2\xa9 2000-2002 Ximian, Inc.\n"
+								  "Copyright \xc2\xa9 2003-2005 Fernando Herrera");
+	gtk_about_dialog_set_authors (GTK_ABOUT_DIALOG (about), authors);
+	gtk_about_dialog_set_documenters (GTK_ABOUT_DIALOG (about), documenters);
+	gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG (about), strcmp (translators, 
+							 "translator_credits-PLEASE_ADD_YOURSELF_HERE") ? translators : NULL);
+	gtk_about_dialog_set_logo_icon_name (GTK_ABOUT_DIALOG (about), "bug-buddy");
 
-	if (pixbuf != NULL)
-		gdk_pixbuf_unref (pixbuf);
-	
 	g_signal_connect (G_OBJECT (about), "destroy",
 			  G_CALLBACK (gtk_widget_destroyed),
 			  &about);
 
-#if 0
-	{
-		GtkWidget *href;
-		href = gnome_href_new ("http://bug-buddy.org/",
-				       _("The lame Bug Buddy web page"));
-		gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (about)->vbox),
-				    href, FALSE, FALSE, 0);
-		gtk_widget_show (href);
-	}
-#endif
 	gtk_window_set_transient_for (GTK_WINDOW (about),
 				      GTK_WINDOW (GET_WIDGET ("druid-window")));
 	gtk_widget_show (about);
@@ -360,12 +345,12 @@ email_is_valid (const char *addy)
 	gboolean is_dot_ok = FALSE;
 	gboolean seen_at  = FALSE;
 	const char *tld = NULL;
-	const unsigned char *s;
+	const char *s;
 	const char **t;
 
 	for (s = addy; *s; s++) {
 		/* Must be in acceptable ASCII range. */
-		if (*s <= 32 || *s >= 128)
+		if ((unsigned char)*s <= 32 || (unsigned char)*s >= 128)
 			return FALSE;
 		if (*s == '.') {
 			/* No dots at start, after at, or two in a row. */
@@ -735,9 +720,9 @@ select_version (GSList *list, char *version)
 
 	if (version && g_slist_find_custom (list, version ,(GCompareFunc)strcmp)!=NULL) {
 		druid_data.version = strdup (version);
-		gtk_option_menu_set_history (GTK_OPTION_MENU (GET_WIDGET ("the-version-menu")),
-					     g_slist_position (list, g_slist_find_custom (list, version, 
-											  (GCompareFunc)strcmp)));
+		gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("the-version-menu")),
+					  g_slist_position (list, g_slist_find_custom (list, version,
+										       (GCompareFunc)strcmp)));
 		return;
 	}
 	 
@@ -750,18 +735,18 @@ select_version (GSList *list, char *version)
 
 		if (g_slist_find_custom (list, xversion ,(GCompareFunc)strcmp)!=NULL) {
 			druid_data.version = strdup (xversion);
-			gtk_option_menu_set_history (GTK_OPTION_MENU (GET_WIDGET ("the-version-menu")),
-						     g_slist_position (list, g_slist_find_custom (list, xversion, 
-												  (GCompareFunc)strcmp)));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("the-version-menu")),
+						  g_slist_position (list, g_slist_find_custom (list, xversion,
+											       (GCompareFunc)strcmp)));
 			g_free (xversion);
 			return;
 		}
 		g_free (xversion);
 	}
 
-	gtk_option_menu_set_history (GTK_OPTION_MENU (GET_WIDGET ("the-version-menu")),
-				     g_slist_position (list, g_slist_find_custom (list, "unspecified", 
-										  (GCompareFunc)strcmp)));
+	gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("the-version-menu")),
+				  g_slist_position (list, g_slist_find_custom (list, "unspecified", 
+									       (GCompareFunc)strcmp)));
 }
 
 static void
@@ -769,9 +754,9 @@ select_severity (GSList *list, char *severity)
 {
 	if (severity && g_slist_find_custom (list, severity, (GCompareFunc)strcmp)!=NULL) {
 		druid_data.severity = strdup (severity);
-		gtk_option_menu_set_history (GTK_OPTION_MENU (GET_WIDGET ("severity-list")),
-					     g_slist_position (list, g_slist_find_custom (list, severity,
-											  (GCompareFunc)strcmp)));
+		gtk_combo_box_set_active (GTK_COMBO_BOX (GET_WIDGET ("severity-list")),
+					  g_slist_position (list, g_slist_find_custom (list, severity,
+										       (GCompareFunc)strcmp)));
 	}
 }
 
